@@ -3,7 +3,7 @@ package ColorTheme::Test::Static;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-06-07'; # DATE
 our $DIST = 'ColorThemeBase-Static'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use strict;
 use warnings;
@@ -16,7 +16,7 @@ our %THEME = (
     colors => {
         color1 => 'ff0000',
         color2 => '00ff00',
-        color3 => '0000ff',
+        color3 => {bg=>'0000ff'},
         color4 => {fg=>'000000', bg=>'ffffff'},
         color5 => sub {
             +{
@@ -42,7 +42,7 @@ ColorTheme::Test::Static - A color theme with static list of colors
 
 =head1 VERSION
 
-This document describes version 0.002 of ColorTheme::Test::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-07.
+This document describes version 0.003 of ColorTheme::Test::Static (from Perl distribution ColorThemeBase-Static), released on 2020-06-07.
 
 =head1 HOMEPAGE
 
